## 1.0.0 (2024-01-24)


### Features

* added error handling to ilcd parsing ([bc9beb9](https://github.com/ocni-dtu/epdx/commit/bc9beb9f478fa4f26292f741cfe4fe04e319360d))
* improved support for js and ts ([c938488](https://github.com/ocni-dtu/epdx/commit/c9384887d395adba7a53ca13ce6b14f6332f5130))
* made it optional to whether convert_ilcd should return string, dict or pydantic ([720ca62](https://github.com/ocni-dtu/epdx/commit/720ca6284597c5f79ef600a4abcc16fa311e9976))
